========================
Pootle 2.9 release notes
========================

*Not yet released*

Welcome to Pootle 2.9!

If you want to try it, check one of the following:

- :doc:`Installation instructions </server/installation>`
- :doc:`Upgrading instructions </server/upgrading>`


Changes
=======

- Pootle FS is enabled by default:

  - All projects are now handled by Pootle FS.
  - When creating new projects:

    - It is mandatory to set filesystem configuration right after creating it,
    - Pootle no longer automatically imports translations from disk,
    - Pootle no longer creates project directory on disk if missing.

  - When adding new languages to a project:

    - Pootle no longer tries to first import existing translations from disk,
    - Pootle initializes the new languages using the templates in the database.

- Several bugfixes for Pootle FS.
- Serialization:

  - Don't cache on serialization
  - Allow serializing obsolete units
  - Serialization and sync bugfixes

- Overall documentation review and updates.
- `pootle` command can now be run with no `VIRTUAL_ENV` environment variable
  set.
- :djadmin:`sync_stores` and :djadmin:`update_stores` commands can now work
  with projects managed by Pootle FS.
- Removed ``changed_languages`` command. Use :djadmin:`list_languages` instead.


Credits
=======

This release was made possible by the following people:

Ryan Northey, Leandro Regueiro, boite.

And to all our bug finders, testers and translators, a Very BIG Thank You.
